import 'package:example/Constants/AppStrings.dart';
import 'package:bui_component/Constants/AppColors.dart';
import 'package:flutter/material.dart';
import 'package:bui_component/DemoComponent.dart';
import 'package:shared_preferences/shared_preferences.dart';
import '../Utils/class_builder.dart';
import 'package:bui_component/DrawerComonent/kfDrawer.dart';
import 'package:bui_component/DataModalComponent/SlidableListView.dart';
import 'package:toast/toast.dart';

class DemoScreen extends KFDrawerContent {
  final Function() onMenuIconPressed;

  DemoScreen({this.onMenuIconPressed});

  @override
  _DemoScreenState createState() => _DemoScreenState();
}

class _DemoScreenState extends State<DemoScreen> {
  Color theme = AppColors.APP_COLOR_PRIMARY;

  @override
  void initState() {
    ClassBuilder.registerClasses();
    getStringValuesSF();
    data = List.generate(20, (index) {
      return index;
    });
    super.initState();
  }

  List<int> data = List();

  List<String> actions = ["Edit", "Delete"];

  getStringValuesSF() async {
    SharedPreferences prefs = await SharedPreferences.getInstance();
    //Return int
    String stringValue = prefs.getString(AppStrings.PRIMARY_THEME_COLOR);

    if (stringValue != null) {
      int colorCodeInt = int.parse(stringValue);
      setState(() {
        theme = Color(colorCodeInt);
        this.mounted;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: DemoComponent(
        onMenuPressed: onMenuPressed,
        backgroundColor: theme,
      ),
    );
  }

  Future<void> onMenuPressed() async {
    setState(() {
      widget.onMenuPressed();
      // widget.onMenuIconPressed();
    });
  }

  Widget get detailsView {
    return Container(
      margin: EdgeInsets.only(top: 30),
      child: SlideListView(
        itemBuilder: (bc, index) {
          return Container(
              width: MediaQuery.of(context).size.width,

              //padding: EdgeInsets.all(10),
              child: Card(
                elevation: 10,
                shape: BeveledRectangleBorder(
                    borderRadius: BorderRadius.only(
                  bottomLeft: Radius.circular(15.0),
                  bottomRight: Radius.circular(15.0),
                  topLeft: Radius.circular(15.0),
                  topRight: Radius.circular(15.0),
                )),
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Container(
                        padding: EdgeInsets.all(10),
                        child: Text(
                          'Child ${data[index]}',
                          style: TextStyle(
                              fontWeight: FontWeight.bold,
                              fontSize: 16,
                              color: Colors.black87),
                        )),
                    Row(
                      crossAxisAlignment: CrossAxisAlignment.center,
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: [
                        Container(
                            padding: EdgeInsets.all(10),
                            child: Text(
                              'Sub Child ${data[index]}',
                              style: TextStyle(
                                  fontWeight: FontWeight.w400,
                                  fontSize: 14,
                                  color: Colors.black87),
                            )),
                        Container(
                            padding: EdgeInsets.all(10),
                            child: Text(
                              'Content ${data[index]}',
                              style: TextStyle(
                                  fontWeight: FontWeight.w400,
                                  fontSize: 14,
                                  color: Colors.black87),
                            )),
                      ],
                    ),
                    /* Container(
                              padding: EdgeInsets.all(10),
                              child: Text(
                                'Sub Child ${data[index]}',
                                style: TextStyle(
                                    fontWeight: FontWeight.w400,
                                    fontSize: 14,
                                    color: Colors.black87),
                              )),
                          Container(
                              padding: EdgeInsets.all(10),
                              child: Text(
                                'Content ${data[index]}',
                                style: TextStyle(
                                    fontWeight: FontWeight.w300,
                                    fontSize: 12,
                                    color: Colors.black87),
                              )),*/
                    InkWell(
                      onTap: () {
                        Toast.show(data[index].toString(), context);
                      },
                      child: Container(
                          decoration: BoxDecoration(
                              color: Colors.grey[200],
                              shape: BoxShape.rectangle,
                              borderRadius: BorderRadius.only(
                                  bottomLeft: Radius.circular(15.0),
                                  bottomRight: Radius.circular(15.0))),
                          alignment: Alignment.bottomRight,
                          padding: EdgeInsets.all(10),
                          child: Text(
                            'View More',
                            style: TextStyle(
                                fontWeight: FontWeight.w900,
                                fontSize: 14,
                                color: Colors.black54),
                          )),
                    ),
                  ],
                ),
              ));
        },
        actionWidgetDelegate:
            ActionWidgetDelegate(actions.length, (actionIndex, listIndex) {
          if (actionIndex == 0) {
            return Column(
              mainAxisSize: MainAxisSize.min,
              children: <Widget>[
                Icon(
                  Icons.edit,
                  color: theme ?? AppColors.primaryColor,
                ),
                Text(
                  actions[0].toString(),
                  style: TextStyle(
                    fontWeight: FontWeight.bold,
                    fontSize: 14,
                    color: theme ?? AppColors.primaryColor,
                  ),
                ),
              ],
            );
          } else {
            return Column(
              mainAxisSize: MainAxisSize.min,
              children: <Widget>[
                Icon(Icons.delete, color: AppColors.errorWarning),
                Text(
                  actions[1].toString(),
                  style: TextStyle(
                      fontWeight: FontWeight.bold,
                      fontSize: 12,
                      color: AppColors.errorWarning),
                ),
              ],
            );
          }

        }, (int indexInList, int index, BaseSlideItem item) {
          if (index == 0) {
            //item.remove();
            item.close();
            _showMyDialog(indexInList, item);
          } else {
            item.close();
            Toast.show("Close this Item", context);
          }
        }, [Colors.white, Colors.white]),
        dataList: data,
        refreshCallback: () async {
          await Future.delayed(Duration(seconds: 2));

          return;
        },
      ),
    );
  }

  Future<void> _showMyDialog(int indexInList, BaseSlideItem item) async {
    return showDialog<void>(
      context: context,
      barrierDismissible: true, // user must tap button!
      builder: (BuildContext context) {
        return AlertDialog(
          title: Text(
            'Warning!!',
            style: TextStyle(
                fontWeight: FontWeight.w900, fontSize: 20, color: Colors.red),
          ),
          content: Text(
            'Are you sure do you want to delete this item?',
            style: TextStyle(
                fontWeight: FontWeight.w700, fontSize: 18, color: Colors.black),
          ),
          actions: <Widget>[
            TextButton(
              child: Text(
                'Okay',
                style: TextStyle(
                    //   fontWeight: FontWeight.w700,
                    fontSize: 16,
                    color: Colors.black54),
              ),
              onPressed: () {
                item.remove();
                Toast.show(
                    "Deleted this Item" + indexInList.toString(), context);
                Navigator.of(context).pop();
              },
            ),
            TextButton(
              child: Text(
                'Cancel',
                style: TextStyle(
                    //fontWeight: FontWeight.w700,
                    fontSize: 16,
                    color: Colors.black54),
              ),
              onPressed: () {
                Navigator.of(context).pop();
              },
            ),
          ],
        );
      },
    );
  }
}
