/*
    Refer License for Terms & Conditions
 */
import 'package:flutter/material.dart';
import 'Constants/AppColors.dart';
import 'Constants/AppStrings.dart';
import 'package:bui_component/ButtonsComponent/buttonComponent.dart';
import 'Constants/fontFamily.dart';
import 'OTPComponent/codeFields.dart';

class OtpScreenComponent extends StatefulWidget {
  final Color backgroundColor;
  final Color buttonColor;
  final String title;
  final GlobalKey globalKey;
  final Function() otpSuccess;
  final Function() onBackPress;
  final Function(String val) validateCondition;

  OtpScreenComponent({
    Key key,
    @required this.backgroundColor,
    @required this.buttonColor,
    @required this.title,
    @required this.globalKey,
    @required this.otpSuccess,
    @required this.onBackPress,
    @required this.validateCondition,
  }) : super(key: key);

  @override
  _OtpScreenComponentState createState() => _OtpScreenComponentState();
}

class _OtpScreenComponentState extends State<OtpScreenComponent> {
  bool isValidOTPErrorMessageShowingText = false;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: widget.backgroundColor != null
          ? widget.backgroundColor
          : AppColors.primaryColor,
      body: ListView(
        children: <Widget>[
          Container(
            padding: EdgeInsets.only(
                top: 60.0, left: 30.0, right: 30.0, bottom: 30.0),
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.center,
              children: <Widget>[
                Center(
                  child: Text(
                    AppStrings.LOGO,
                    style: TextStyle(
                        color: Colors.white,
                        fontSize: 50.0,
                        fontFamily: FontFamily.Gilroy),
                    textAlign: TextAlign.center,
                  ),
                ),
              ],
            ),
          ),
          _mobilWidget,
        ],
      ),
    );
  }

  Widget get _mobilWidget {
    return Container(
      child: Container(
        width: MediaQuery.of(context).size.width,
        height: MediaQuery.of(context).size.height * 0.9,
        padding: EdgeInsets.symmetric(horizontal: 20.0),
        decoration: BoxDecoration(
          color: Colors.white,
          borderRadius: BorderRadius.only(
            topLeft: Radius.circular(5.0),
            topRight: Radius.circular(5.0),
          ),
        ),
        child: Form(
          key: widget.globalKey,
          child: Column(
            children: [
              Container(
                padding: EdgeInsets.all(20),
                child: Text(
                  AppStrings.VERIFICATION,
                  style: TextStyle(
                    fontFamily: FontFamily.Gilroy,
                    fontSize: 20,
                    color: widget.backgroundColor != null
                        ? widget.backgroundColor
                        : AppColors.primaryColor,
                  ),
                  textAlign: TextAlign.center,
                ),
              ),
              CodeFields(
                closeOnFinish: true,
                fieldWidth: 38,
                focusedBorderColor: widget.backgroundColor,
                enabledBorder: AppColors.halfWhite,
                fieldHeight: 61.0,
                keyboardType: TextInputType.number,
                length: 6,
                autofocus: true,
                validator: (val) {
                  widget.validateCondition(val);
                  if (val.length == 0) {
                    return AppStrings.OTP_CANNOT_BE_EMPTY;
                  } else if (val.length != 6) {
                    return AppStrings.PLEASE_COMPLETE_THE_OTP;
                  } else {
                    return null;
                  }
                },
                inputDecoration: InputDecoration(
                  filled: true,
                  fillColor: Colors.grey.withOpacity(0.1),
                  enabledBorder: OutlineInputBorder(
                      borderRadius: BorderRadius.circular(12.0),
                      borderSide: BorderSide(
                        color: widget.backgroundColor != null
                            ? widget.backgroundColor
                            : AppColors.primaryColor,
                      )),
                  border: OutlineInputBorder(
                    borderRadius: BorderRadius.circular(12.0),
                  ),
                ),
              ),
              SizedBox(
                height: 20,
              ),
              Button.mini(
                btnColor: widget.backgroundColor ?? AppColors.APP_COLOR_PRIMARY,
                width: MediaQuery.of(context).size.width * 0.4,
                onPressed: () {
                  widget.otpSuccess();
                },
                elevation: 20,
                buttonType: ButtonType.custom,
                btnText: AppStrings.CONFIRM,
                btnTextColor: AppColors.APP_COLOR_WHITE,
              ),
              SizedBox(
                height: 20,
              ),
            ],
          ),
        ),
      ),
    );
  }

  String validateCode(String value) {}
}
